@@ -19,10 +19,6 @@ known_drivers = {
 
 
 class AlertDriver(object):
-    def __init__(self, logger, args):
-        self.logger = logger
-        self.args = args
-
     def send_alert(self, message, device_id):
         raise NotImplementedError()
 
